.. _ontwenning:


.. raw:: html

    <br>
    <center>

ontwenning
==========

.. raw:: html

    </center>
    <br>


Ontwenningsverschijnselen bij antipsychotica:

1) misselijkheid
2) duizeligheid
3) overgeven
4) heet of koud voelen
5) verminderde eetlust
6) spierpijn
7) overmatig zweten
8) trillen
9) slapeloosheid
10) vreemde gevoelsgewaarwording (bijvoorbeeld het gevoel hebben dat er mieren over de huid kruipen)
11) rusteloosheid
12) angst
13) diarree
14) loopneus

